-- $Id: Atlas_ClassicWoW.lua 18 2017-01-16 10:57:05Z arith $
--[[

	Atlas, a World of Warcraft instance map browser
	Copyright 2011 ~ 2017 - Arith Hsu, Atlas Team <atlas.addon at gmail dot com>

	This file is part of Atlas.

	Atlas is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Atlas is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Atlas; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]

local BZ = Atlas_GetLocaleLibBabble("LibBabble-SubZone-3.0");
local BF = Atlas_GetLocaleLibBabble("LibBabble-Faction-3.0");
local L = LibStub("AceLocale-3.0"):GetLocale("Atlas_ClassicWoW");
local ALC = LibStub("AceLocale-3.0"):GetLocale("Atlas");
local ALIL = Atlas_IngameLocales;

local BLUE = "|cff6666ff";
local GREN = "|cff66cc33";
local GREY = "|cff999999";
local LBLU = "|cff33cccc";
local _RED = "|cffcc3333";
local ORNG = "|cffcc9933";
local PINK = "|ccfcc33cc";
local PURP = "|cff9900ff";
local WHIT = "|cffffffff";
local YLOW = "|cffcccc33";
local INDENT = "      ";

local myMaps = {
--************************************************
-- Kalimdor Instances (Classic)
--************************************************

	BlackfathomDeepsEnt = {
		ZoneName = { BZ["Blackfathom Deeps"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Ashenvale"] };
		LevelRange = "22-25";
		MinLevel = "20";
		PlayerLimit = "5";
		Acronym = L["BFD"];
		WorldMapID = "688";
		JournalInstanceID = "227";
		Module = "Atlas_ClassicWoW";
		NextMap = "BlackfathomDeeps";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..BZ["Blackfathom Deeps"], 10002 };
	};
	BlackfathomDeeps = {
		ZoneName = { BZ["Blackfathom Deeps"] };
		Location = { BZ["Ashenvale"] };
		DungeonID = "10";
		Acronym = L["BFD"];
		WorldMapID = "688";
		JournalInstanceID = "227";
		Module = "Atlas_ClassicWoW";
		PrevMap = "BlackfathomDeepsEnt";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Je'neu Sancrea <The Earthen Ring>"] };
		{ GREN..INDENT..L["Sentinel Aluwyn"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Zeya"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ BLUE.." B) "..ALC["Connection"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Ghamoo-ra", 368), 368 };
		{ WHIT.." 2) "..Atlas_GetBossName("Domina", 436), 436 };
		{ GREN..INDENT..L["Altar of Blood"] };
		{ WHIT.." 3) "..Atlas_GetBossName("Subjugator Kor'ul", 426), 426 };
		{ GREN..INDENT..L["Altar of Blood"] };
		{ WHIT.." 4) "..Atlas_GetBossName("Thruk", 1145), 1145 };
		{ WHIT.." 5) "..Atlas_GetBossName("Guardian of the Deep", 447), 447 };
		{ WHIT.." 6) "..Atlas_GetBossName("Executioner Gore", 1144), 1144 };
		{ WHIT.." 7) "..Atlas_GetBossName("Twilight Lord Bathiel", 437), 437 };
		{ GREN..INDENT..L["Fire of Aku'mai"] };
		{ WHIT.." 8) "..Atlas_GetBossName("Aku'mai", 444), 444 };
		{ GREN..INDENT..L["Spoils of Blackfathom"] };
		{ GREN..INDENT..L["Sentinel Aluwyn"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Zeya"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
	};
	DireMaulEnt = {
		ZoneName = { BZ["Dire Maul"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Feralas"] };
		LevelRange = "38-47";
		MinLevel = "36";
		PlayerLimit = "5";
		Acronym = L["DM"];
		WorldMapID = "699";
		JournalInstanceID = "230";
		Module = "Atlas_ClassicWoW";
		NextMap = "DireMaulEast";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..BZ["Dire Maul"]..ALC["L-Parenthesis"]..ALC["East"]..ALC["R-Parenthesis"], 10002 };
		{ BLUE.." C) "..BZ["Dire Maul"]..ALC["L-Parenthesis"]..ALC["North"]..ALC["R-Parenthesis"], 10003 };
		{ BLUE.." D) "..BZ["Dire Maul"]..ALC["L-Parenthesis"]..ALC["West"]..ALC["R-Parenthesis"], 10004 };
		{ GREN.." 1') "..L["Dire Pool"], 10005 };
		{ GREN.." 2') "..L["Dire Maul Arena"], 10006 };
		{ GREN..INDENT..L["Elder Mistwalker"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"] };
	};
	DireMaulEast = {
		ZoneName = { BZ["Dire Maul"]..ALC["L-Parenthesis"]..ALC["East"]..ALC["R-Parenthesis"] };
		Location = { BZ["Feralas"] };
		DungeonID = "34";
		Acronym = L["DM"];
		WorldMapID = "699";
		DungeonLevel = "6";
		JournalInstanceID = "230";
		Module = "Atlas_ClassicWoW";
		PrevMap = "DireMaulEnt";
		NextMap = "DireMaulNorth";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["\"Ambassador\" Dagg'thol"] };
		{ GREN..INDENT..L["Furgus Warpwood"] };
		{ BLUE.." B) "..ALC["Entrance"], 10002 };
		{ BLUE.." C) "..ALC["Entrance"], 10003 };
		{ BLUE.." D) "..ALC["Connection"], 10004 };
		{ BLUE.." E) "..ALC["Exit"], 10005 };
		{ WHIT.." 1) "..Atlas_GetBossName("Lethtendris", 404), 404 };
		{ WHIT..INDENT..Atlas_GetBossName("Pimgib") };
		{ WHIT.." 2) "..Atlas_GetBossName("Hydrospawn", 403), 403 };
		{ WHIT.." 3) "..Atlas_GetBossName("Zevrim Thornhoof", 402)..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"], 402 };
		{ WHIT.." 4) "..Atlas_GetBossName("Alzzin the Wildshaper", 405), 405 };
		{ GREN.." 1') "..Atlas_GetBossName("Pusillin")..ALC["L-Parenthesis"]..L["Chase Begins"]..ALC["R-Parenthesis"], 10006 };
		{ GREN.." 2') "..Atlas_GetBossName("Pusillin")..ALC["L-Parenthesis"]..L["Chase Ends"]..ALC["R-Parenthesis"], 10007 };
		{ GREN.." 3') "..L["Old Ironbark"]..ALC["Slash"]..L["Ironbark the Redeemed"], 10008 };
	};
	DireMaulNorth = {
		ZoneName = { BZ["Dire Maul"]..ALC["L-Parenthesis"]..ALC["North"]..ALC["R-Parenthesis"] };
		Location = { BZ["Feralas"] };
		DungeonID = "36";
		Acronym = L["DM"];
		WorldMapID = "699";
		DungeonLevel = "1";
		JournalInstanceID = "230";
		Module = "Atlas_ClassicWoW";
		PrevMap = "DireMaulEast";
		NextMap = "DireMaulWest";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Druid of the Talon"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Stonemaul Ogre"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Guard Mol'dar", 411), 411 };
		{ WHIT.." 2) "..Atlas_GetBossName("Stomper Kreeg", 412), 412 };
		{ WHIT.." 3) "..Atlas_GetBossName("Guard Fengus", 413), 413 };
		{ WHIT.." 4) "..Atlas_GetBossName("Guard Slip'kik", 414), 414 };
		{ GREN..INDENT..L["Knot Thimblejack"] };
		{ WHIT.." 5) "..Atlas_GetBossName("Captain Kromcrush", 415), 415 };
		{ WHIT.." 6) "..Atlas_GetBossName("King Gordok", 417), 417 };
		{ WHIT..INDENT..Atlas_GetBossName("Cho'Rush the Observer", 416), 416 };
	};
	DireMaulWest = {
		ZoneName = { BZ["Dire Maul"]..ALC["L-Parenthesis"]..ALC["West"]..ALC["R-Parenthesis"] };
		Location = { BZ["Feralas"] };
		DungeonID = "38";
		Acronym = L["DM"];
		WorldMapID = "699";
		DungeonLevel = "4";
		JournalInstanceID = "230";
		Module = "Atlas_ClassicWoW";
		PrevMap = "DireMaulNorth";
		{ ORNG..ALC["Key"]..ALC["Colon"]..ALIL["J'eevee's Jar"]..ALC["L-Parenthesis"]..Atlas_GetBossName("Lord Hel'nurath")..ALC["R-Parenthesis"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B-E) "..ALC["Connection"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Tendris Warpwood", 406), 406 };
		{ WHIT.." 2) "..Atlas_GetBossName("Magister Kalendris", 408), 408 };
		{ WHIT.." 3) "..Atlas_GetBossName("Illyanna Ravenoak", 407), 407 };
		{ WHIT..INDENT..L["Ferra"] };
		{ WHIT.." 4) "..Atlas_GetBossName("Immol'thar", 409), 409 };
		{ ORNG..INDENT..Atlas_GetBossName("Lord Hel'nurath")..ALC["L-Parenthesis"]..ALC["Summon"]..ALC["R-Parenthesis"] };
		{ WHIT.." 5) "..Atlas_GetBossName("Prince Tortheldrin", 410), 410 };
		{ ORNG.." 1) "..Atlas_GetBossName("Tsu'zee")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"], 10008 };
		{ GREN.." 1') "..L["Estulan <The Highborne>"], 10003 };
		{ GREN..INDENT..L["Shen'dralar Watcher"] };
		{ GREN.." 2') "..L["Pylons"], 10004 };
		{ GREN.." 3') "..L["Ancient Equine Spirit"], 10005 };
		{ GREN.." 4') "..L["Shen'dralar Ancient"], 10006 };
		{ GREN.." 5') "..BZ["The Athenaeum"], 10007 };
		{ GREN..INDENT..L["Falrin Treeshaper"] };
		{ GREN..INDENT..L["Lorekeeper Lydros"] };
		{ GREN..INDENT..L["Lorekeeper Javon"] };
		{ GREN..INDENT..L["Lorekeeper Kildrath"] };
		{ GREN..INDENT..L["Lorekeeper Mykos"] };
		{ GREN..INDENT..L["Shen'dralar Provisioner"] };
	};
	MaraudonEnt = {
		ZoneName = { BZ["Maraudon"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Desolace"] };
		LevelRange = "32-39";
		MinLevel = "30";
		PlayerLimit = "5";
		Acronym = L["Mara"];
		WorldMapID = "750";
		JournalInstanceID = "232";
		Module = "Atlas_ClassicWoW";
		NextMap = "Maraudon";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ ORNG..INDENT..L["Cursed Centaur"]..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["Comma"]..ALC["Wanders"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..L["The Nameless Prophet"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["R-Parenthesis"] };
		{ BLUE.." B) "..BZ["Maraudon"]..ALC["L-Parenthesis"]..ALC["Purple"]..ALC["R-Parenthesis"], 10002 };
		{ BLUE.." C) "..BZ["Maraudon"]..ALC["L-Parenthesis"]..ALC["Orange"]..ALC["R-Parenthesis"], 10003 };
		{ BLUE.." D) "..BZ["Maraudon"]..ALC["L-Parenthesis"]..ALC["Portal"]..ALC["Comma"]..ALC["Lower"]..ALC["R-Parenthesis"], 10004 };
		{ GREN.." 1') "..L["Kherrah"]..ALC["L-Parenthesis"]..ALC["Lower"]..ALC["R-Parenthesis"], 10005 };
	};
	Maraudon = {
		ZoneName = { BZ["Maraudon"] };
		Location = { BZ["Desolace"] };
		LevelRange = "32-39";
		MinLevel = "30";
		PlayerLimit = "5";
		Acronym = L["Mara"];
		WorldMapID = "750";
		JournalInstanceID = "232";
		Module = "Atlas_ClassicWoW";
		PrevMap = "MaraudonEnt";
		{ BLUE.." A) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Orange"]..ALC["R-Parenthesis"], 10001 };
		{ BLUE.." B) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Purple"]..ALC["R-Parenthesis"], 10002 };
		{ BLUE.." C) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Portal"]..ALC["R-Parenthesis"], 10003 };
		{ WHIT.." 1) "..Atlas_GetBossName("Noxxion", 423), 423 };
		{ WHIT.." 2) "..Atlas_GetBossName("Razorlash", 424), 424 };
		{ WHIT.." 3) "..Atlas_GetBossName("Lord Vyletongue", 427), 427 };
		{ WHIT.." 4) "..Atlas_GetBossName("Tinkerer Gizlock", 425), 425 };
		{ WHIT.." 5) "..Atlas_GetBossName("Celebras the Cursed", 428), 428 };
		{ GREN..INDENT..L["Celebras the Redeemed"] };
		{ WHIT.." 6) "..Atlas_GetBossName("Landslide", 429), 429 };
		{ WHIT.." 7) "..Atlas_GetBossName("Rotgrip", 430), 430 };
		{ WHIT.." 8) "..Atlas_GetBossName("Princess Theradras", 431), 431 };
		{ ORNG.." 1) "..Atlas_GetBossName("Meshlok the Harvester")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["Comma"]..ALC["Wanders"]..ALC["R-Parenthesis"], 10004 };
		{ GREN.." 1') "..L["Elder Splitrock"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10005 };
	};
	RagefireChasm = {
		ZoneName = { BZ["Ragefire Chasm"] };
		Location = { BZ["Orgrimmar"] };
		DungeonID = "4";
		Acronym = L["RFC"];
		WorldMapID = "680";
		JournalInstanceID = "226";
		Module = "Atlas_ClassicWoW";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Adarogg", 694), 694 };
		{ WHIT.." 2) "..Atlas_GetBossName("Dark Shaman Koranthal", 695), 695 };
		{ WHIT.." 3) "..Atlas_GetBossName("Slagmaw", 696), 696 };
		{ WHIT.." 4) "..Atlas_GetBossName("Lava Guard Gordoth", 697), 697 };
		{ GREN.." 1') "..L["Commander Bagran"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"], 10002 };
		{ GREN..INDENT..L["Invoker Xorenth"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN.." 2') "..L["Scout Cage"], 10003 };
	};
	RazorfenDowns = {
		ZoneName = { BZ["Razorfen Downs"] };
		Location = { BZ["Thousand Needles"] };
		DungeonID = "20";
		Acronym = L["RFD"];
		WorldMapID = "760";
		JournalInstanceID = "233";
		Module = "Atlas_ClassicWoW";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Koristrasza"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Aarux", 1142), 1142 };
		{ WHIT.." 2) "..Atlas_GetBossName("Mordresh Fire Eye", 433), 433 };
		{ WHIT.." 3) "..Atlas_GetBossName("Mushlump", 1143)..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 1143 };
		{ GREN..INDENT..L["Koristrasza"] };
		{ WHIT.." 4) "..Atlas_GetBossName("Death Speaker Blackthorn", 1146), 1146 };
		{ WHIT..INDENT..Atlas_GetBossName("Amnennar the Coldbringer", 1141), 1141 };
		{ GREN..INDENT..L["Amnennar's Phylactery"] };
	};
	RazorfenKraul = {
		ZoneName = { BZ["Razorfen Kraul"] };
		Location = { BZ["Southern Barrens"] };
		DungeonID = "16";
		Acronym = L["RFK"];
		WorldMapID = "761";
		JournalInstanceID = "234";
		Module = "Atlas_ClassicWoW";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Auld Stonespire"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Hunter Bonetusk", 896), 896 };
		{ WHIT.." 2) "..Atlas_GetBossName("Roogug", 895), 895 };
		{ WHIT.." 3) "..Atlas_GetBossName("Warlord Ramtusk", 899), 899 };
		{ WHIT.." 4) "..Atlas_GetBossName("Groyat, the Blind Hunter", 900), 900 };
		{ WHIT.." 5) "..Atlas_GetBossName("Charlga Razorflank", 901), 901 };
		{ ORNG.." 1) "..Atlas_GetBossName("Earthcaller Halmgar")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"], 10002 };
		{ GREN.." 1') "..L["Spirit of Agamaggan <Ancient>"], 10003 };
	};
	TheRuinsofAhnQiraj = {
		ZoneName = { BZ["Ahn'Qiraj"]..ALC["Colon"]..BZ["Ruins of Ahn'Qiraj"] };
		Location = { BZ["Ahn'Qiraj: The Fallen Kingdom"] };
		DungeonID = "160";
		Acronym = L["AQ10"];
		PlayerLimit = "10";
		WorldMapID = "717";
		JournalInstanceID = "743";
		Module = "Atlas_ClassicWoW";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Cenarion Circle"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Kurinnaxx", 1537), 1537 };
		{ GREN..INDENT..Atlas_GetBossName("Lieutenant General Andorov") };
		{ GREN..INDENT..L["Four Kaldorei Elites"] };
		{ WHIT.." 2) "..Atlas_GetBossName("General Rajaxx", 1538), 1538 };
		{ WHIT..INDENT..L["Captain Qeez"] };
		{ WHIT..INDENT..L["Captain Tuubid"] };
		{ WHIT..INDENT..L["Captain Drenn"] };
		{ WHIT..INDENT..L["Captain Xurrem"] };
		{ WHIT..INDENT..L["Major Yeggeth"] };
		{ WHIT..INDENT..L["Major Pakkon"] };
		{ WHIT..INDENT..L["Colonel Zerran"] };
		{ WHIT.." 3) "..Atlas_GetBossName("Moam", 1539)..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 1539 };
		{ WHIT.." 4) "..Atlas_GetBossName("Buru the Gorger", 1540)..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 1540 };
		{ WHIT.." 5) "..Atlas_GetBossName("Ayamiss the Hunter", 1541)..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 1541 };
		{ WHIT.." 6) "..Atlas_GetBossName("Ossirian the Unscarred", 1542), 1542 };
		{ GREN.." 1') "..L["Safe Room"], 10008 };
	};
	TheTempleofAhnQiraj = {
		ZoneName = { BZ["Ahn'Qiraj"]..ALC["Colon"]..BZ["Temple of Ahn'Qiraj"] };
		Location = { BZ["Ahn'Qiraj: The Fallen Kingdom"] };
		DungeonID = "161";
		Acronym = L["AQ40"];
		PlayerLimit = "40";
		WorldMapID = "766";
		JournalInstanceID = "744";
		Module = "Atlas_ClassicWoW";
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Brood of Nozdormu"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B-D) "..ALC["Connection"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("The Prophet Skeram", 1543)..ALC["L-Parenthesis"]..ALC["Outside"]..ALC["R-Parenthesis"], 1543 };
		{ WHIT.." 2) "..Atlas_GetBossName("The Bug Family")..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 10004 };
		{ WHIT..INDENT..Atlas_GetBossName("Vem") };
		{ WHIT..INDENT..Atlas_GetBossName("Lord Kri") };
		{ WHIT..INDENT..Atlas_GetBossName("Princess Yauj") };
		{ WHIT.." 3) "..Atlas_GetBossName("Battleguard Sartura", 1544), 1544 };
		{ WHIT.." 4) "..Atlas_GetBossName("Fankriss the Unyielding", 1545), 1545 };
		{ WHIT.." 5) "..Atlas_GetBossName("Viscidus", 1548)..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 1548 };
		{ WHIT.." 6) "..Atlas_GetBossName("Princess Huhuran", 1546), 1546 };
		{ WHIT.." 7) "..Atlas_GetBossName("The Twin Emperors", 1549), 1549 };
		{ WHIT..INDENT..Atlas_GetBossName("Emperor Vek'lor") };
		{ WHIT..INDENT..Atlas_GetBossName("Emperor Vek'nilash") };
		{ GREN..INDENT..ALC["Teleporter destination"] };
		{ WHIT.." 8) "..Atlas_GetBossName("Ouro", 1550)..ALC["L-Parenthesis"]..ALC["Optional"]..ALC["R-Parenthesis"], 1550 };
		{ WHIT.." 9) "..Atlas_GetBossName("C'Thun", 1551), 1551 };
		{ GREN.." 1') "..L["Andorgos <Brood of Malygos>"]..ALC["L-Parenthesis"]..ALC["Teleporter"]..ALC["R-Parenthesis"], 10012 };
		{ GREN..INDENT..L["Vethsera <Brood of Ysera>"] };
		{ GREN..INDENT..L["Kandrostrasz <Brood of Alexstrasza>"] };
		{ GREN.." 2') "..L["Arygos"], 10013 };
		{ GREN..INDENT..L["Caelestrasz"] };
		{ GREN..INDENT..L["Merithra of the Dream"] };
		{ GREN..INDENT..ALC["Teleporter destination"] };
		--Atlas_GetBossName("Silithid Royalty", 1547)
	};
	WailingCavernsEnt = {
		ZoneName = { BZ["Wailing Caverns"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Northern Barrens"] };
		DungeonID = "1";
		Acronym = L["WC"];
		WorldMapID = "749";
		JournalInstanceID = "240";
		Module = "Atlas_ClassicWoW";
		NextMap = "WailingCaverns";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..BZ["Wailing Caverns"], 10002 };
		{ ORNG.." 1) "..Atlas_GetBossName("Trigore the Lasher")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"], 10003 };
		{ ORNG..INDENT..Atlas_GetBossName("Boahn")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"] };
	};
	WailingCaverns = {
		ZoneName = { BZ["Wailing Caverns"] };
		Location = { BZ["Northern Barrens"] };
		DungeonID = "1";
		Acronym = L["WC"];
		WorldMapID = "749";
		DungeonLevel = "1";
		JournalInstanceID = "240";
		Module = "Atlas_ClassicWoW";
		PrevMap = "WailingCavernsEnt";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Lady Anacondra", 474), 474 };
		{ WHIT.." 2) "..Atlas_GetBossName("Lord Pythas", 476), 476 };
		{ WHIT.." 3) "..Atlas_GetBossName("Lord Cobrahn", 475), 475 };
		{ WHIT.." 4) "..Atlas_GetBossName("Skum", 478), 478 };
		{ WHIT.." 5) "..Atlas_GetBossName("Lord Serpentis", 479)..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"], 479 };
		{ WHIT.." 6) "..Atlas_GetBossName("Verdan the Everliving", 480)..ALC["L-Parenthesis"]..ALC["Upper"]..ALC["R-Parenthesis"], 480 };
		{ WHIT.." 7) "..Atlas_GetBossName("Mutanus the Devourer", 481), 481 };
		{ GREN..INDENT..L["Naralex"] };
		{ ORNG.." 1) "..Atlas_GetBossName("Kresh", 477)..ALC["L-Parenthesis"]..ALC["Varies"]..ALC["R-Parenthesis"], 477 };
		{ ORNG.." 2) "..Atlas_GetBossName("Deviate Faerie Dragon")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["Comma"]..ALC["Varies"]..ALC["R-Parenthesis"], 10002 };
		{ GREN.." 1') "..L["Ebru <Disciple of Naralex>"], 10003 };
		{ GREN..INDENT..L["Nalpak <Disciple of Naralex>"] };
		{ GREN..INDENT..L["Muyoh <Disciple of Naralex>"] };
	};
	ZulFarrak = {
		ZoneName = { BZ["Zul'Farrak"] };
		Location = { BZ["Tanaris"] };
		DungeonID = "24";
		Acronym = L["ZF"];
		WorldMapID = "686";
		JournalInstanceID = "241";
		Module = "Atlas_ClassicWoW";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..L["Chief Engineer Bilgewhizzle <Gadgetzan Water Co.>"] };
		{ GREN..INDENT..L["Mazoga's Spirit"] };
		{ GREN..INDENT..L["Tran'rek"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Gahz'rilla", 483)..ALC["L-Parenthesis"]..ALC["Summon"]..ALC["R-Parenthesis"], 483 };
		{ WHIT.." 2) "..Atlas_GetBossName("Sandfury Executioner") };
		{ WHIT..INDENT..L["Weegli Blastfuse"] };
		{ WHIT..INDENT..Atlas_GetBossName("Sergeant Bly") };
		{ WHIT..INDENT..L["Raven"] };
		{ WHIT..INDENT..Atlas_GetBossName("Oro Eyegouge") };
		{ WHIT..INDENT..Atlas_GetBossName("Murta Grimgut") };
		{ WHIT.." 3) "..Atlas_GetBossName("Nekrum Gutchewer and Shadow Priest Sezz'ziz", 487), 487 };
		{ WHIT.." 4) "..Atlas_GetBossName("Chief Ukorz Sandscalp", 489), 489 };
		{ WHIT..INDENT..Atlas_GetBossName("Ruuzlu") };
		{ WHIT.." 5) "..Atlas_GetBossName("Witch Doctor Zum'rah", 486), 486 };
		{ WHIT.." 6) "..Atlas_GetBossName("Antu'sul", 484), 484 };
		{ ORNG.." 1) "..Atlas_GetBossName("Sandarr Dunereaver")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"], 10002 };
		{ ORNG.." 2) "..Atlas_GetBossName("Hydromancer Velratha", 482), 482 };
		{ ORNG.." 3) "..Atlas_GetBossName("Theka the Martyr", 485), 485 };
		{ ORNG.." 4) "..Atlas_GetBossName("Dustwraith")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["Comma"]..ALC["Varies"]..ALC["R-Parenthesis"], 10003 };
		{ ORNG.." 5) "..Atlas_GetBossName("Zerillis")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["Comma"]..ALC["Wanders"]..ALC["R-Parenthesis"], 10004 };
		{ GREN.." 1') "..L["Elder Wildmane"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10005 };
	};

--************************************************
-- Eastern Kingdoms Instances (Classic)
--************************************************
	
	BlackrockDepths = {
		ZoneName = { BZ["Blackrock Mountain"]..ALC["Colon"]..BZ["Blackrock Depths"] };
		Location = { BZ["Searing Gorge"]..ALC["Slash"]..BZ["Burning Steppes"] };
		LevelRange = "49-56";
		MinLevel = "47";
		PlayerLimit = "5";
		Acronym = L["BRD"];
		WorldMapID = "704";
		JournalInstanceID = "228";
		Module = "Atlas_ClassicWoW";
		{ ORNG..ALC["Key"]..ALC["Colon"]..ALIL["Relic Coffer Key"] };
		{ ORNG..ALC["Key"]..ALC["Colon"]..ALIL["Dark Keeper Key"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B-D) "..ALC["Connection"], 10002 };
		{ BLUE.." E) "..BZ["The Molten Core"], 10003 };
		{ WHIT.." 1) "..Atlas_GetBossName("High Interrogator Gerstahn", 369), 369 };
		{ WHIT.." 2) "..Atlas_GetBossName("Lord Roccor", 370)..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 370 };
		{ WHIT.." 3) "..Atlas_GetBossName("Houndmaster Grebmar", 371), 371 };
		{ WHIT.." 4) "..Atlas_GetBossName("Bael'Gar", 377), 377 };
		{ WHIT.." 5) "..Atlas_GetBossName("Lord Incendius", 374), 374 };
		{ GREN..INDENT..L["The Black Anvil"] };
		{ WHIT.." 6) "..Atlas_GetBossName("Fineous Darkvire", 376)..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 376 };
		{ WHIT.." 7) "..L["The Vault"] };
		{ WHIT..INDENT..Atlas_GetBossName("Warder Stilgiss", 375), 375 };
		{ WHIT..INDENT..Atlas_GetBossName("Verek") };
		{ WHIT..INDENT..L["Watchman Doomgrip"] };
		{ WHIT.." 8) "..Atlas_GetBossName("Pyromancer Loregrain", 373), 373 };
		{ WHIT.." 9) "..Atlas_GetBossName("Ring of Law", 372), 372 };
		{ ORNG..INDENT..Atlas_GetBossName("High Justice Grimstone", 372, 1), 372 };
		{ WHIT..INDENT..Atlas_GetBossName("Anub'shiah")..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Eviscerator")..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Gorosh the Dervish")..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Grizzle")..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Hedrum the Creeper")..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ WHIT..INDENT..Atlas_GetBossName("Ok'thor the Breaker")..ALC["L-Parenthesis"]..ALC["Random"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Elder Morndeep"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"] };
		{ WHIT.."10) "..Atlas_GetBossName("General Angerforge", 378), 378 };
		{ WHIT.."11) "..Atlas_GetBossName("Golem Lord Argelmach", 379), 379 };
		{ GREN..INDENT..L["Schematic: Field Repair Bot 74A"] };
		{ GREN..INDENT..ALC["Blacksmithing Plans"] };
		{ WHIT.."12) "..Atlas_GetBossName("Hurley Blackbreath", 380), 380 };
		{ ORNG..INDENT..Atlas_GetBossName("Coren Direbrew")..ALC["L-Parenthesis"]..ALC["Brewfest"]..ALC["R-Parenthesis"] };
		{ WHIT.."13) "..Atlas_GetBossName("Ribbly Screwspigot", 382), 382 };
		{ WHIT.."14) "..Atlas_GetBossName("Phalanx", 381), 381 };
		{ WHIT..INDENT..Atlas_GetBossName("Plugger Spazzring", 383), 383 };
		{ GREN..INDENT..L["Private Rocknot"] };
		{ GREN..INDENT..L["Mistress Nagmara"] }; 
		{ WHIT.."15) "..Atlas_GetBossName("Ambassador Flamelash", 384), 384 };
		{ WHIT.."16) "..Atlas_GetBossName("The Seven", 385), 385 };
		{ WHIT.."17) "..Atlas_GetBossName("Magmus", 386), 386 };
		{ WHIT.."18) "..Atlas_GetBossName("Emperor Dagran Thaurissan", 387), 387 };
		{ WHIT..INDENT..Atlas_GetBossName("Princess Moira Bronzebeard") };
		{ WHIT..INDENT..Atlas_GetBossName("High Priestess of Thaurissan") };
		{ ORNG.." 1) "..Atlas_GetBossName("Panzor the Invincible")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["Comma"]..ALC["Wanders"]..ALC["R-Parenthesis"], 10004 };
		{ GREN.." 1') "..L["Jalinda Sprig <Morgan's Militia>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10005 };
		{ GREN..INDENT..L["Oralius <Morgan's Militia>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Thal'trak Proudtusk <Kargath Expeditionary Force>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Galamav the Marksman <Kargath Expeditionary Force>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Maxwort Uberglint"] };
		{ GREN..INDENT..L["Tinkee Steamboil"] };
		{ GREN..INDENT..L["Yuka Screwspigot <Engineering Supplies>"] };
		{ GREN..INDENT..L["Abandonded Mole Machine"] };
		{ GREN.." 2') "..L["Kevin Dawson <Morgan's Militia>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10006 };
		{ GREN..INDENT..L["Lexlort <Kargath Expeditionary Force>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN.." 3') "..L["Prospector Seymour <Morgan's Militia>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10007 };
		{ GREN..INDENT..L["Razal'blade <Kargath Expeditionary Force>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN.." 4') "..L["Abandonded Mole Machine"], 10008 };
		{ GREN.." 5') "..L["The Shadowforge Lock"], 10009 };
		{ GREN.." 6') "..ALC["Blacksmithing Plans"], 10010 };
		{ GREN.." 7') "..L["Mayara Brightwing <Morgan's Militia>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10011 };
		{ GREN..INDENT..L["Hierophant Theodora Mulvadania <Kargath Expeditionary Force>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN.." 8') "..L["Lokhtos Darkbargainer <The Thorium Brotherhood>"], 10012 };
		{ GREN.." 9') "..L["Abandonded Mole Machine"], 10013 };
		{ GREN.."10') "..L["Mountaineer Orfus <Morgan's Militia>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10014 };
		{ GREN..INDENT..L["Thunderheart <Kargath Expeditionary Force>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN.."11') "..L["Marshal Maxwell <Morgan's Militia>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10015 };
		{ GREN..INDENT..L["Warlord Goretooth <Kargath Expeditionary Force>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN.."12') "..L["The Black Forge"], 10016 };
		{ GREN.."13') "..L["Core Fragment"], 10017 };
		{ GREN.."14') "..L["Shadowforge Brazier"], 10018 };
	};
	BlackwingLair = {
		ZoneName = { BZ["Blackrock Mountain"]..ALC["Colon"]..BZ["Blackwing Lair"] };
		Location = { BZ["Searing Gorge"]..ALC["Slash"]..BZ["Burning Steppes"] };
		DungeonID = "50";
		PlayerLimit = "40";
		WorldMapID = "755";
		JournalInstanceID = "742";
		Acronym = L["BWL"];
		Module = "Atlas_ClassicWoW";
		{ ORNG..ALC["Attunement Required"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B-C) "..ALC["Connection"], 10002 };
		{ WHIT.." 1) "..Atlas_GetBossName("Grethok the Controller"), 10003 };
		{ GREN..INDENT..L["Orb of Domination"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Razorgore the Untamed", 1529), 1529 };
		{ WHIT.." 3) "..Atlas_GetBossName("Vaelastrasz the Corrupt", 1530), 1530 };
		{ WHIT.." 4) "..Atlas_GetBossName("Broodlord Lashlayer", 1531), 1531 };
		{ WHIT.." 5) "..Atlas_GetBossName("Firemaw", 1532), 1532 };
		{ WHIT.." 6) "..Atlas_GetBossName("Ebonroc", 1533), 1533 };
		{ WHIT..INDENT..L["Master Elemental Shaper Krixix"] };
		{ WHIT.." 7) "..Atlas_GetBossName("Flamegor", 1534), 1534 };
		{ WHIT.." 8) "..Atlas_GetBossName("Chromaggus", 1535), 1535 };
		{ WHIT.." 9) "..Atlas_GetBossName("Nefarian", 1536), 1536 };
	};
	GnomereganEnt = {
		ZoneName = { BZ["Gnomeregan"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Dun Morogh"] };
		DungeonID = "14";
		Acronym = L["Gnome"];
		WorldMapID = "691";
		JournalInstanceID = "231";
		Module = "Atlas_ClassicWoW";
		NextMap = "Gnomeregan";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..ALC["Meeting Stone"] };
		{ BLUE.." B) "..BZ["Gnomeregan"]..ALC["L-Parenthesis"]..ALC["Front"]..ALC["R-Parenthesis"], 10002 };
		{ BLUE.." C) "..BZ["Gnomeregan"]..ALC["L-Parenthesis"]..ALC["Back"]..ALC["R-Parenthesis"], 10003 };
		{ GREN.." 1') "..ALC["Elevator"], 10004 };
		{ GREN..INDENT..L["Torben Zapblast <Teleportation Specialist>"] };
		{ GREN.." 2') "..L["Mail Box"], 10005 };
	};
	Gnomeregan = {
		ZoneName = { BZ["Gnomeregan"] };
		Location = { BZ["Dun Morogh"] };
		DungeonID = "14";
		Acronym = L["Gnome"];
		WorldMapID = "691";
		JournalInstanceID = "231";
		Module = "Atlas_ClassicWoW";
		PrevMap = "GnomereganEnt";
		{ BLUE.." A) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Front"]..ALC["R-Parenthesis"], 10001 };
		{ BLUE.." B) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Back"]..ALC["R-Parenthesis"], 10002 };
		{ BLUE.." C-F) "..ALC["Connection"], 10003 };
		{ WHIT.." 1) "..Atlas_GetBossName("Grubbis", 419), 419 };
		{ WHIT..INDENT..L["Chomper"] };
		{ GREN..INDENT..L["Blastmaster Emi Shortfuse"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Viscous Fallout", 420)..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 420 };
		{ WHIT.." 3) "..Atlas_GetBossName("Electrocutioner 6000", 421), 421 };
		{ WHIT.." 4) "..Atlas_GetBossName("Crowd Pummeler 9-60", 418), 418 };
		{ WHIT.." 5) "..Atlas_GetBossName("Mekgineer Thermaplugg", 422), 422 };
		{ GREN.." 1') "..L["Murd Doc <S.A.F.E.>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10004 };
		{ GREN.." 2') "..BZ["The Clean Zone"], 10005 };
		{ GREN..INDENT..L["Tink Sprocketwhistle <Engineering Supplies>"] };
		{ GREN..INDENT..L["The Sparklematic 5200"] };
		{ GREN..INDENT..ALC["Mail Box"] };
		{ GREN.." 3') "..L["B.E Barechus <S.A.F.E.>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10006 };
		{ GREN.." 4') "..L["Face <S.A.F.E.>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10007 };
		{ GREN.." 5') "..L["Hann Ibal <S.A.F.E.>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10008 };
	};
	LowerBlackrockSpire = {
		ZoneName = { BZ["Blackrock Mountain"]..ALC["Colon"]..BZ["Lower Blackrock Spire"] };
		Location = { BZ["Searing Gorge"]..ALC["Slash"]..BZ["Burning Steppes"] };
		DungeonID = "32";
		Acronym = L["LBRS"];
		WorldMapID = "721";
		JournalInstanceID = "229";
		Module = "Atlas_ClassicWoW";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..BZ["Blackrock Mountain"], 10002 };
		{ BLUE.." C) "..BZ["Upper Blackrock Spire"], 10003 };
		{ BLUE.." D-G) "..ALC["Connection"], 10004 };
		{ WHIT.." 1) "..Atlas_GetBossName("Highlord Omokk", 388), 388 };
		{ WHIT.." 2) "..Atlas_GetBossName("Shadow Hunter Vosh'gajin", 389), 389 };
		{ WHIT.." 3) "..Atlas_GetBossName("War Master Voone", 390), 390 };
		{ WHIT.." 4) "..Atlas_GetBossName("Mother Smolderweb", 391), 391 };
		{ WHIT.." 5) "..Atlas_GetBossName("Urok Doomhowl", 392)..ALC["L-Parenthesis"]..ALC["Summon"]..ALC["R-Parenthesis"], 392 };
		{ GREN..INDENT..L["Urok's Tribute Pile"] };
		{ WHIT.." 6) "..Atlas_GetBossName("Quartermaster Zigris", 393), 393 };
		{ WHIT.." 7) "..Atlas_GetBossName("Halycon", 394), 394 };
		{ WHIT..INDENT..Atlas_GetBossName("Gizrul the Slavener", 395), 395 };
		{ WHIT.." 8) "..Atlas_GetBossName("Overlord Wyrmthalak", 396), 396 };
		{ ORNG.." 1) "..Atlas_GetBossName("Burning Felguard")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["Comma"]..ALC["Summon"]..ALC["R-Parenthesis"], 10005 };
		{ ORNG.." 2) "..Atlas_GetBossName("Spirestone Butcher")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"], 10006 };
		{ ORNG.." 3) "..Atlas_GetBossName("Spirestone Battle Lord")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"], 10007 };
		{ ORNG..INDENT..Atlas_GetBossName("Spirestone Lord Magus")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"] };
		{ ORNG.." 4) "..Atlas_GetBossName("Bannok Grimaxe")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"], 10008 };
		{ ORNG.." 5) "..Atlas_GetBossName("Crystal Fang")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"], 10009 };
		{ ORNG.." 6) "..Atlas_GetBossName("Ghok Bashguud")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"], 10010 };
		{ GREN.." 1') "..L["Acride <Scarshield Legion>"], 10011 };
		{ GREN.." 2') "..L["Elder Stonefort"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10012 };
		{ GREN.." 3') "..L["Roughshod Pike"], 10013 };
	};
	MoltenCore = {
		ZoneName = { BZ["Blackrock Mountain"]..ALC["Colon"]..BZ["The Molten Core"] };
		Location = { BZ["Searing Gorge"]..ALC["Slash"]..BZ["Burning Steppes"] };
		DungeonID = "48";
		Acronym = L["MC"];
		PlayerLimit = "40";
		WorldMapID = "696";
		JournalInstanceID = "741";
		Module = "Atlas_ClassicWoW";
		{ ORNG..ALC["Attunement Required"] };
		{ ORNG..REPUTATION..ALC["Colon"]..BF["Hydraxian Waterlords"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Lucifron", 1519), 1519 };
		{ WHIT.." 2) "..Atlas_GetBossName("Magmadar", 1520), 1520 };
		{ WHIT.." 3) "..Atlas_GetBossName("Gehennas", 1521), 1521 };
		{ WHIT.." 4) "..Atlas_GetBossName("Garr", 1522), 1522 };
		{ WHIT.." 5) "..Atlas_GetBossName("Shazzrah", 1523), 1523 };
		{ WHIT.." 6) "..Atlas_GetBossName("Baron Geddon", 1524), 1524 };
		{ WHIT.." 7) "..Atlas_GetBossName("Golemagg the Incinerator", 1526), 1526 };
		{ WHIT.." 8) "..Atlas_GetBossName("Sulfuron Harbinger", 1525), 1525 };
		{ WHIT.." 9) "..Atlas_GetBossName("Majordomo Executus", 1527), 1527 };
		{ WHIT.."10) "..Atlas_GetBossName("Ragnaros", 1528), 1528 };
	};
	StratholmeCrusader = {
		ZoneName = { BZ["Stratholme"]..ALC["Hyphen"]..BZ["Crusaders' Square"] };
		Location = { BZ["Eastern Plaguelands"] };
		DungeonID = "40";
		Acronym = L["Strat"];
		WorldMapID = "765";
		DungeonLevel = "1";
		JournalInstanceID = "236";
		Module = "Atlas_ClassicWoW";
		NextMap = "StratholmeGauntlet";
		{ BLUE.." A) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Front"]..ALC["R-Parenthesis"], 10001 };
		{ GREN..INDENT..L["Crusade Commander Eligor Dawnbringer <Brotherhood of the Light>"] };
		{ GREN..INDENT..L["Master Craftsman Wilhelm <Brotherhood of the Light>"] };
		{ GREN..INDENT..L["Packmaster Stonebruiser <Brotherhood of the Light>"] };
		{ WHIT.." 1) "..Atlas_GetBossName("The Unforgiven", 450), 450 };
		{ WHIT.." 2) "..Atlas_GetBossName("Timmy the Cruel", 445), 445 };
		{ WHIT.." 3) "..Atlas_GetBossName("Commander Malor", 749), 749 };
		{ WHIT.." 4) "..Atlas_GetBossName("Willey Hopebreaker", 446), 446 };
		{ WHIT.." 5) "..Atlas_GetBossName("Instructor Galford", 448), 448 };
		{ WHIT.." 6) "..Atlas_GetBossName("Balnazzar", 449), 449 };
		{ ORNG.." 1) "..L["Stratholme Courier"], 10002 };
		{ ORNG..INDENT..Atlas_GetBossName("Skul")..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Fras Siabi's Postbox"] };
		{ ORNG.." 2) "..Atlas_GetBossName("Hearthsinger Forresten", 443)..ALC["L-Parenthesis"]..ALC["Varies"]..ALC["R-Parenthesis"], 10003 , 443 };
		{ ORNG.." 3) "..Atlas_GetBossName("Risen Hammersmith")..ALC["L-Parenthesis"]..ALC["Summon"]..ALC["R-Parenthesis"], 10004 };
		{ GREN..INDENT..ALC["Blacksmithing Plans"] };
		{ GREN.." 1') "..L["King's Square Postbox"], 10005 };
		{ GREN.." 2') "..L["Festival Lane Postbox"], 10006 };
		{ GREN.." 3') "..L["Elder Farwhisper"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10007 };
		{ GREN.." 4') "..L["Market Row Postbox"], 10008 };
		{ GREN..INDENT..Atlas_GetBossName("Postmaster Malown")..ALC["L-Parenthesis"]..ALC["Varies"]..ALC["R-Parenthesis"] };
	};
	StratholmeGauntlet = {
		ZoneName = { BZ["Stratholme"]..ALC["Hyphen"]..BZ["The Gauntlet"] };
		Location = { BZ["Eastern Plaguelands"] };
		DungeonID = "274";
		Acronym = L["Strat"];
		WorldMapID = "765";
		DungeonLevel = "2";
		JournalInstanceID = "236";
		Module = "Atlas_ClassicWoW";
		PrevMap = "StratholmeCrusader";
		{ BLUE.." A) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Front"]..ALC["R-Parenthesis"], 10001 };
		{ GREN..INDENT..L["Packmaster Stonebruiser <Brotherhood of the Light>"] };
		{ WHIT.." 1) "..Atlas_GetBossName("Baroness Anastari", 451), 451 };
		{ WHIT.." 2) "..Atlas_GetBossName("Nerub'enkan", 452), 452 };
		{ WHIT.." 3) "..Atlas_GetBossName("Maleki the Pallid", 453), 453 };
		{ WHIT.." 4) "..Atlas_GetBossName("Magistrate Barthilas", 454)..ALC["L-Parenthesis"]..ALC["Varies"]..ALC["R-Parenthesis"], 454 };
		{ WHIT.." 5) "..Atlas_GetBossName("Ramstein the Gorger", 455), 455 };
		{ WHIT.." 6) "..Atlas_GetBossName("Lord Aurius Rivendare", 456), 456 };
		{ ORNG.." 1) "..Atlas_GetBossName("Black Guard Swordsmith")..ALC["L-Parenthesis"]..ALC["Summon"]..ALC["R-Parenthesis"], 10003 };
		{ GREN..INDENT..ALC["Blacksmithing Plans"] };
		{ GREN.." 1') "..L["Archmage Angela Dosantos <Brotherhood of the Light>"], 10002 };
		{ GREN..INDENT..L["Crusade Commander Eligor Dawnbringer <Brotherhood of the Light>"] };
		{ GREN..INDENT..L["Crusade Commander Korfax <Brotherhood of the Light>"] };
		{ GREN..INDENT..L["Master Craftsman Wilhelm <Brotherhood of the Light>"] };
	};
	TheStockade = {
		ZoneName = { BZ["The Stockade"] };
		Location = { BZ["Stormwind City"] };
		DungeonID = "12";
		Acronym = L["Stocks"];
		WorldMapID = "690";
		JournalInstanceID = "238";
		Module = "Atlas_ClassicWoW";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Randolph Moloch", 466), 466 };
		{ WHIT.." 2) "..Atlas_GetBossName("Hogger", 464), 464 };
		{ WHIT.." 3) "..Atlas_GetBossName("Lord Overheat", 465), 465 };
		{ GREN.." 1') "..L["Rifle Commander Coe"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10002 };
		{ GREN.." 2') "..L["Warden Thelwater"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10003 };
		{ GREN.." 3') "..L["Nurse Lillian"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10004 };
	};
	TheSunkenTempleEnt = {
		ZoneName = { BZ["Sunken Temple"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Swamp of Sorrows"] };
		DungeonID = "28";
		Acronym = L["ST"];
		WorldMapID = "687";
		JournalInstanceID = "237";
		Module = "Atlas_ClassicWoW";
		NextMap = "TheSunkenTemple";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ GREN..INDENT..ALC["Meeting Stone"] };
		{ GREN..INDENT..L["Lord Itharius"] };
		{ BLUE.." B) "..BZ["Sunken Temple"], 10002 };
		{ WHIT.." 1) "..L["Priestess Udum'bra"], 10003 };
		{ WHIT.." 2) "..L["Gomora the Bloodletter"], 10004 };
		{ WHIT.." 3) "..Atlas_GetBossName("Jammal'an the Prophet", 458), 10005 , 458 };
		{ ORNG.." 1) "..L["Captain Wyrmak"]..ALC["L-Parenthesis"]..ALC["Rare"]..ALC["R-Parenthesis"], 10006 };
	};
	TheSunkenTemple = {
		ZoneName = { BZ["Sunken Temple"] };
		Location = { BZ["Swamp of Sorrows"] };
		DungeonID = "28";
		Acronym = L["ST"];
		WorldMapID = "687";
		JournalInstanceID = "237";
		Module = "Atlas_ClassicWoW";
		PrevMap = "TheSunkenTempleEnt";
		{ ORNG..ALC["AKA"]..ALC["Colon"]..BZ["The Temple of Atal'Hakkar"] };
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ WHIT.." 1) "..Atlas_GetBossName("Avatar of Hakkar", 457), 457 };
		{ WHIT.." 2) "..Atlas_GetBossName("Jammal'an the Prophet", 458), 458 };
		{ WHIT..INDENT..Atlas_GetBossName("Ogom the Wretched") };
		{ WHIT.." 3) "..Atlas_GetBossName("Dreamscythe", 459, 1)..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 459 };
		{ WHIT..INDENT..Atlas_GetBossName("Weaver", 459, 2)..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 459 };
		{ WHIT.." 4) "..Atlas_GetBossName("Hazzas", 459, 4)..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 459 };
		{ WHIT..INDENT..Atlas_GetBossName("Morphaz", 459, 3)..ALC["L-Parenthesis"]..ALC["Wanders"]..ALC["R-Parenthesis"], 459 };
		{ WHIT.." 5) "..Atlas_GetBossName("Shade of Eranikus", 463), 463 };
		{ GREN.." 1') "..L["Lord Itharius"], 10002 };
		{ GREN.." 2') "..L["Elder Starsong"]..ALC["L-Parenthesis"]..ALC["Lunar Festival"]..ALC["R-Parenthesis"], 10003 };
	};
	UldamanEnt = {
		ZoneName = { BZ["Uldaman"]..ALC["L-Parenthesis"]..ALC["Entrance"]..ALC["R-Parenthesis"] };
		Location = { BZ["Badlands"] };
		DungeonID = "22";
		Acronym = L["Ulda"];
		WorldMapID = "692";
		JournalInstanceID = "239";
		Module = "Atlas_ClassicWoW";
		NextMap = "Uldaman";
		{ BLUE.." A) "..ALC["Entrance"], 10001 };
		{ BLUE.." B) "..BZ["Uldaman"], 10002 };
	};
	Uldaman = {
		ZoneName = { BZ["Uldaman"] };
		Location = { BZ["Badlands"] };
		DungeonID = "22";
		Acronym = L["Ulda"];
		WorldMapID = "692";
		JournalInstanceID = "239";
		Module = "Atlas_ClassicWoW";
		PrevMap = "UldamanEnt";
		{ BLUE.." A) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Front"]..ALC["R-Parenthesis"], 10001 };
		{ BLUE.." B) "..ALC["Entrance"]..ALC["L-Parenthesis"]..ALC["Back"]..ALC["R-Parenthesis"], 10002 };
		{ BLUE.." C) "..ALC["Connection"], 10003 };
		{ WHIT.." 1) "..Atlas_GetBossName("The Lost Dwarves", 468)..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"], 468 };
		{ WHIT..INDENT..Atlas_GetBossName("Olaf", 468, 3), 468 };
		{ WHIT..INDENT..Atlas_GetBossName("Eric \"The Swift\"", 468, 2), 468 };
		{ WHIT..INDENT..Atlas_GetBossName("Baelog", 468, 1), 468 };
		{ GREN..INDENT..L["Baelog's Chest"] };
		{ WHIT.." 2) "..Atlas_GetBossName("Revelosh", 467), 467 };
		{ WHIT.." 3) "..Atlas_GetBossName("Ironaya", 469), 469 };
		{ WHIT.." 4) "..Atlas_GetBossName("Obsidian Sentinel", 748), 748 };
		{ WHIT.." 5) "..Atlas_GetBossName("Ancient Stone Keeper", 470), 470 };
		{ WHIT.." 6) "..Atlas_GetBossName("Galgann Firehammer", 471), 471 };
		{ WHIT.." 7) "..Atlas_GetBossName("Grimlok", 472), 472 };
		{ WHIT.." 8) "..Atlas_GetBossName("Archaedas", 473), 473 };
		{ GREN.." 1') "..L["Kand Sandseeker <Explorer's League>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"], 10004 };
		{ GREN..INDENT..L["Lead Prospector Durdin <Explorer's League>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Olga Runesworn <Explorer's League>"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Aoren Sunglow <The Reliquary>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["High Examiner Tae'thelan Bloodwatcher <The Reliquary>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN..INDENT..L["Lidia Sunglow <The Reliquary>"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		{ GREN.." 2') "..L["Ancient Treasure"], 10005 };
		{ GREN..INDENT..L["The Discs of Norgannon"] };
	};
};

for k, v in pairs(myMaps) do
	AtlasMaps[k] = v;
end
